# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,acep_result)
S3method(plot,acep_result)
S3method(print,acep_corpus)
S3method(print,acep_result)
S3method(summary,acep_corpus)
S3method(summary,acep_result)
export("%>%")
export(acep_claude)
export(acep_clean)
export(acep_clear_regex_cache)
export(acep_context)
export(acep_corpus)
export(acep_count)
export(acep_db)
export(acep_detect)
export(acep_extract)
export(acep_frec)
export(acep_gemini)
export(acep_gpt)
export(acep_gpt_schema)
export(acep_int)
export(acep_load_base)
export(acep_may)
export(acep_min)
export(acep_ollama)
export(acep_ollama_setup)
export(acep_openrouter)
export(acep_pipeline)
export(acep_plot_rst)
export(acep_plot_st)
export(acep_postag)
export(acep_postag_hibrido)
export(acep_process_chunks)
export(acep_regex_cache_size)
export(acep_result)
export(acep_sst)
export(acep_svo)
export(acep_together)
export(acep_token)
export(acep_token_plot)
export(acep_token_table)
export(acep_upos)
export(pipe_clean)
export(pipe_count)
export(pipe_intensity)
export(pipe_timeseries)
importFrom(graphics,barplot)
importFrom(graphics,par)
importFrom(graphics,title)
importFrom(httr,GET)
importFrom(httr,http_error)
importFrom(httr,status_code)
importFrom(httr,timeout)
importFrom(jsonlite,read_json)
importFrom(jsonlite,write_json)
importFrom(magrittr,"%>%")
importFrom(stats,aggregate)
importFrom(stats,ave)
importFrom(stats,setNames)
importFrom(stringr,str_count)
importFrom(stringr,str_extract_all)
importFrom(stringr,str_replace_all)
importFrom(utils,download.file)
importFrom(utils,head)
importFrom(utils,install.packages)
