## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = FALSE,
  comment = "#>"
)

## ----titulares, results = TRUE, warning = FALSE, message = FALSE, eval=require("tibble")----
library(ACEP)

titulares <- c(acep_bases$titulares, "Hola mundo.")

titulares

## ----tt, eval=FALSE-----------------------------------------------------------
# titulares_tags <- acep_postag(
#   texto = titulares,
#   core = "es_core_news_lg", # valor por defecto
#   bajar_core = FALSE,       # el valor por defecto es TRUE
#   inst_spacy = FALSE,       # valor por defecto
#   inst_miniconda = FALSE,   # valor por defecto
#   inst_reticulate = FALSE   # valor por defecto
# )
# 
# str(titulares_tags)

## ----postag00, eval=require("tibble"), message=FALSE, warning=FALSE, echo=FALSE----
texto_entity <- subset(acep_bases$spacy_postag, entity != "")
titulares_tags <- list(
  texto_tag = acep_bases$spacy_postag,
  texto_tag_entity = texto_entity,
  texto_only_entity = data.frame(
    entity = texto_entity$token,
    entity_type = sub("_.*", "", texto_entity$entity),
    doc_id = texto_entity$doc_id,
    sentence = texto_entity$sentence
  ),
  texto_only_entity_loc = data.frame(
    entity_ = "Mar del Plata",
    doc_id = 1L,
    sentence = 1L,
    entity = "Mar_del_Plata",
    entity_type = "LOC",
    lat = -38.0055,
    long = -57.5426
  ),
  texto_nounphrase = acep_bases$spacy_postag,
  texto_only_nounphrase = subset(acep_bases$spacy_postag, nounphrase != "")
)
str(titulares_tags)

## ----postag01-----------------------------------------------------------------
head(titulares_tags$texto_tag, n = 12)

## ----postag02-----------------------------------------------------------------
head(titulares_tags$texto_tag_entity, n = 14)

## ----postag03-----------------------------------------------------------------
head(titulares_tags$texto_only_entity, n = 10)

## ----postag04-----------------------------------------------------------------
head(titulares_tags$texto_only_entity_loc[ , c(1:3, 6:7)], n = 4)

## ----postag05-----------------------------------------------------------------
head(titulares_tags$texto_nounphrase[ , c(1:2, 4, 6)], n = 10)

## ----postag06-----------------------------------------------------------------
head(titulares_tags$texto_only_nounphrase, n = 10)

## ----titulares2, results = TRUE, warning = FALSE, message = FALSE, eval=require("tibble")----
library(ACEP)

titulares <- c(acep_bases$titulares, "Hola mundo.")

titulares

## ----t, eval=FALSE------------------------------------------------------------
# titulares_utags <- acep_upos(
#   texto = titulares,
#   modelo = "spanish" # valor por defecto
# )
# 
# str(titulares_utags)

## ----upos, eval=require("tibble"), message=FALSE, warning=FALSE, echo=FALSE----
titulares_utags <- acep_bases$spacy_postag
str(titulares_utags)

## ----svo01, eval=requireNamespace("rsyntax", quietly = TRUE) && require("tibble")----
titulares_svo <- acep_svo(titulares_utags)

str(titulares_svo)

## ----svo02, eval=requireNamespace("rsyntax", quietly = TRUE) && require("tibble")----
head(titulares_svo$acep_annotate_svo, n=20)

## ----svo03, eval=requireNamespace("rsyntax", quietly = TRUE) && require("tibble")----
head(titulares_svo$acep_pro_svo, n=10)

## ----svo04, eval=requireNamespace("rsyntax", quietly = TRUE) && require("tibble")----
head(titulares_svo$acep_list_svo, n=10)

## ----svo05, eval=requireNamespace("rsyntax", quietly = TRUE) && require("tibble")----
head(titulares_svo$acep_sp, n=10)

## ----svo06, eval=requireNamespace("rsyntax", quietly = TRUE) && require("tibble")----
head(titulares_svo$acep_lista_lemmas, n=10)

## ----svo07, eval=requireNamespace("rsyntax", quietly = TRUE) && require("tibble")----
head(titulares_svo$acep_no_procesadas, n=10)

