utils::globalVariables(c("lat", "feats", "clause", "clause_fill", "doc_id", "objeto", "paragraph_id", "sentence", "sentence_txt", "token", "verbo", "dep_rel", "token_id", "clause2", "upos", "relation", "sujetos", "verbos", "predicados", "lemma", "entity_type", "sent_", "s_v_o", "s_p", "pos", "s_v_o_fill", "lemma_", "conjugaciones", "eventos", "n", "sent", "parent", "sent.x", "sent.y"))
