## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = FALSE,
  comment = "#>"
)

## ----cargar base,results = FALSE, warning = FALSE, message = FALSE, eval=require("tibble")----
library(ACEP)

base <- c(
  "La Fraternidad anunció un paro de trenes en noviembre.",
  "Trabajadores del transporte reclamaron mejoras salariales."
)

## ----token, eval=require("tibble"), message=FALSE-----------------------------
tweets <- acep_token(base[1:2])

head(tweets)

## ----limpia, message=FALSE----------------------------------------------------
base_limpia <- acep_clean(base)

## ----tabla, eval=require("tibble"), message=FALSE-----------------------------
tabla_tokenizada <- acep_token(base_limpia)
head(tabla_tokenizada)

## ----table, eval=require("tibble"), message=FALSE-----------------------------
acep_token_table(tabla_tokenizada$tokens, u = 15)

## ----plot, message=FALSE------------------------------------------------------
acep_token_plot(tabla_tokenizada$tokens, u = 15)

