% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/acep_count.R
\name{acep_clear_regex_cache}
\alias{acep_clear_regex_cache}
\title{Limpiar caché de expresiones regulares}
\usage{
acep_clear_regex_cache()
}
\value{
Devuelve `NULL` invisiblemente.
}
\description{
Elimina todos los patrones regex almacenados en el caché interno de `acep_count()`.
Útil para liberar memoria cuando se han procesado muchos diccionarios diferentes
o cuando se quiere forzar la recompilación de patrones.
}
\examples{
# Limpiar el caché
acep_clear_regex_cache()
}
