% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/acep_pipeline.R
\name{\%>\%}
\alias{\%>\%}
\title{Pipe operator para ACEP}
\usage{
lhs \%>\% rhs
}
\description{
Pipe operator para ACEP
}
\keyword{internal}
