% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/acep_count.R
\name{acep_regex_cache_size}
\alias{acep_regex_cache_size}
\title{Consultar tamaño del caché de regex}
\usage{
acep_regex_cache_size()
}
\value{
Número entero con la cantidad de patrones en caché.
}
\description{
Devuelve el número de patrones regex almacenados actualmente en el caché
interno de `acep_count()`. Cada diccionario único genera una entrada en el caché.
}
\examples{
# Ver cuántos patrones hay en caché
acep_regex_cache_size()
}
