% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/acep_claude.R, R/acep_gpt.R
\name{proteger_arrays_schema}
\alias{proteger_arrays_schema}
\title{Funcion auxiliar para proteger arrays en esquemas JSON}
\usage{
proteger_arrays_schema(schema)

proteger_arrays_schema(schema)
}
\arguments{
\item{schema}{Esquema JSON como lista de R}
}
\value{
Esquema con arrays protegidos

Esquema con arrays protegidos
}
\description{
Protege arrays en esquemas JSON para evitar que jsonlite::toJSON los convierta
incorrectamente. Aplica I() a campos 'required' y 'enum' recursivamente.

Protege arrays en esquemas JSON para evitar que jsonlite::toJSON los convierta
incorrectamente. Aplica I() a campos 'required' y 'enum' recursivamente.
}
\keyword{internal}
