% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_provider.R
\name{.acep_provider_post}
\alias{.acep_provider_post}
\title{Ejecutar una peticion POST a un proveedor de IA}
\usage{
.acep_provider_post(url, headers, body, timeout = 120, encode = "raw")
}
\description{
Centraliza la construccion de la peticion HTTP comun a los proveedores en la
nube: serializa el cuerpo a JSON con `auto_unbox = TRUE`, arma las cabeceras,
aplica un timeout y realiza el POST. El ensamblado del `body` y el parseo de
la respuesta siguen siendo especificos de cada proveedor.
}
\keyword{internal}
