% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/acep_count.R
\name{.acep_count_pattern}
\alias{.acep_count_pattern}
\title{Crear patrón regex para diccionarios de conteo}
\usage{
.acep_count_pattern(dic)
}
\description{
Escapa los metacaracteres de cada término (para tratarlos como texto literal,
evitando coincidencias accidentales o errores de regex) y convierte un espacio
inicial o final en un límite de palabra (\\b), de modo que " paro " coincida
solo con la palabra completa.
}
\keyword{internal}
